@@ -8,13 +8,12 @@ licence: https://opensource.org/licenses/MIT
 import os
 import string
 import logging
-from io import BytesIO
 from itertools import accumulate
 
 from ..binary import ceildiv
 from ..struct import little_endian as le, sizeof
 from ..storage import loaders, savers
-from ..streams import FileFormatError
+from ..magic import FileFormatError, Magic
 from ..font import Font
 from ..glyph import Glyph
 from ..properties import Props
@@ -29,18 +28,32 @@ _ID_DR = b'DRFONT '
 
 
 @loaders.register(
-    'cpi',
-    magic=(b'\xff'+_ID_MS, b'\xff'+_ID_NT, b'\x7f'+_ID_DR),
-    name='cpi'
+    name='cpi',
+    magic=(
+        b'\xff'+_ID_MS,
+        b'\xff'+_ID_NT,
+        b'\x7f'+_ID_DR,
+    ),
+    patterns=('*.cpi',),
 )
-def load_cpi(instream, where=None):
+def load_cpi(instream):
     """Load character-cell fonts from DOS Codepage Information (.CPI) file."""
     data = instream.read()
     fonts = _parse_cpi(data)
     return fonts
 
-@loaders.register('cp', name='kbd')
-def load_cp(instream, where=None):
+
+@loaders.register(
+    name='kbd',
+    patterns=('*.cp',),
+    magic=(
+        # FONT
+        Magic.offset(6) + b'\1\0' + Magic.offset(20) + b'\1\0',
+        # DRFONT
+        Magic.offset(6) + b'\1\0' + Magic.offset(20) + b'\2\0',
+    ),
+)
+def load_cp(instream):
     """Load character-cell fonts from Linux Keyboard Codepage (.CP) file."""
     data = instream.read()
     fonts, _ = _parse_cp(data, 0, standalone=True)
@@ -49,7 +62,7 @@ def load_cp(instream, where=None):
 
 @savers.register(linked=load_cp)
 def save_cp(
-        fonts, outstream, where=None,
+        fonts, outstream,
         version:str=_ID_MS, codepage_prefix:str='cp'
     ):
     """
@@ -72,7 +85,7 @@ def save_cp(
 
 @savers.register(linked=load_cpi)
 def save_cpi(
-        fonts, outstream, where=None,
+        fonts, outstream,
         version:str=_ID_MS, codepage_prefix:str='cp'
     ):
     """
