@@ -13,7 +13,7 @@ from ..properties import Props
 from ..storage import loaders, savers
 from ..font import Font
 from ..glyph import Glyph
-from ..streams import FileFormatError
+from ..magic import FileFormatError, Magic
 from ..binary import bytes_to_bits, ceildiv
 from ..raster import Raster
 
@@ -22,10 +22,12 @@ from .windows import _normalise_metrics
 
 
 @loaders.register(
-    'gft', 'cga', 'ega', 'vga', #'fnt'
-    name='gdos'
+    name='gdos',
+    patterns=('*.fnt', '*.gft', '*.[cev]ga'),
+    # maybe - this is the usual value for 'lighten' and 'skew'
+    magic=(Magic.offset(62) + b'UUUU',),
 )
-def load_gdos(instream, where=None, endianness:str=''):
+def load_gdos(instream, endianness:str=''):
     """
     Load font from Atari GDOS/GEM .FNT file.
 
@@ -46,7 +48,7 @@ def load_gdos(instream, where=None, endianness:str=''):
 
 
 @savers.register(linked=load_gdos)
-def save_gdos(fonts, outstream, where=None, endianness:str='little'):
+def save_gdos(fonts, outstream, endianness:str='little'):
     """
     Save font to Atari GDOS/GEM .FNT file.
 
