@@ -26,7 +26,7 @@ from ..glyph import Glyph
 from ..raster import Raster
 from ..labels import Tag, Char
 from ..storage import loaders, savers
-from ..streams import FileFormatError
+from ..magic import FileFormatError
 from .windows.fnt import _WEIGHT_MAP
 
 # errors that invalidates only one strike or resource, not the whole file
@@ -47,7 +47,7 @@ SFNT_MAGIC = b'\0\1\0\0'
 
 if ttLib:
     @loaders.register(
-        'otb', 'ttf', 'otf', 'woff', 'tte',
+        name='sfnt',
         magic=(
             SFNT_MAGIC,
             # alternative headers which also occur:
@@ -58,10 +58,11 @@ if ttLib:
             # WOFF
             b'wOFF',
         ),
-        name='sfnt',
+        patterns=('*.otb', '*.ttf', '*.otf', '*.woff', '*.tte',),
     )
+    # pylint: disable=function-redefined
     def load_sfnt(
-            infile, where=None,
+            infile,
             hmtx:bool=False, vmtx:bool=False,
             hhea:bool=False, vhea:bool=False,
             os_2:bool=True
@@ -83,15 +84,15 @@ if ttLib:
 
 
     @loaders.register(
-        'ttc', 'otc',
+        name='ttcf',
         magic=(
             # TrueType
             b'ttcf',
         ),
-        name='ttcf',
+        patterns=('*.ttc', '*.otc'),
     )
     def load_collection(
-            infile, where=None,
+            infile,
             hmtx:bool=False, vmtx:bool=False,
             hhea:bool=False, vhea:bool=False,
             os_2:bool=True
@@ -214,7 +215,7 @@ def _read_collection(instream, tags):
         try:
             ttfc_data.append(_sfnt_props(ttf, tags))
         except ResourceFormatError as e:
-            logging.warning(e)
+            logging.debug(e)
     return ttfc_data
 
 
@@ -231,7 +232,7 @@ def _sfnt_props(ttf, tags):
         except (TTLibError, AssertionError) as e:
             if not str(e):
                 e = f'{type(e).__name__} in fontTools library.'
-            logging.warning('Could not read `%s` table in sfnt: %s', tag, e)
+            logging.debug('Could not read `%s` table in sfnt: %s', tag, e)
     return Props(**_to_props(tables))
 
 
@@ -419,7 +420,7 @@ _UNICODE_CHOICES = (
     # Unicode platform, full repertoire
     (0, 4),
     (0, 6),
-    # Windows platform, full repertoiire
+    # Windows platform, full repertoire
     (3, 10),
     # Unicode platform BMP
     (0, 3),
